@@ -23,7 +23,7 @@ from httpx.models import (
     URLTypes,
 )
 
-from pysjtu.ocr import NNRecognizer, Recognizer
+from pysjtu.ocr import JCSSRecognizer, Recognizer
 from . import consts
 from .exceptions import DumpWarning, LoadWarning, LoginException, ServiceUnavailable, SessionException
 from .utils import FileTypes
@@ -114,7 +114,7 @@ class Session(BaseSession):
                  session_file: FileTypes = None, retry: list = None, proxies: ProxiesTypes = None,
                  timeout: TimeoutTypes = None, base_url: str = "https://i.sjtu.edu.cn", _mocker_app=None):
         self._client = httpx.Client(app=_mocker_app, proxies=proxies)
-        self._ocr = ocr if ocr else NNRecognizer()
+        self._ocr = ocr if ocr else JCSSRecognizer()
         self._username = ""
         self._password = ""
         self._cache_store = {}
@@ -589,7 +589,7 @@ class Session(BaseSession):
         """
         self._cache_store = {}
         for i in self._retry:
-            login_page_req = self._secure_req(partial(self.get, consts.LOGIN_URL, validate_session=False))
+            login_page_req = self._secure_req(partial(self.get, consts.LOGIN_URL, validate_session=False, headers=consts.HEADERS))
             uuid = re.findall(r"(?<=uuid\": ').*(?=')", login_page_req.text)[0]
             login_params = {k: v[0] for k, v in parse_qs(urlparse(str(login_page_req.url)).query).items()}
 
